@@ -1,12 +1,11 @@
 package Sys::Info::Constants;
+$Sys::Info::Constants::VERSION = '0.7805';
 use strict;
 use warnings;
-use vars qw( $VERSION @EXPORT_OK %EXPORT_TAGS );
+
 use Carp qw( croak );
 use base qw( Exporter );
 
-$VERSION = '0.7803';
-
 BEGIN {
     if ( ! defined &OSID ) {
         my %OS = (
@@ -47,7 +46,7 @@ use constant NEW_PERL       => $] >= 5.008;
 
 use constant USER_REAL_NAME_FIELD => 6;
 
-%EXPORT_TAGS = (
+our %EXPORT_TAGS = (
     device_cpu => [qw/
                     DCPU_LOAD_LAST_01
                     DCPU_LOAD_LAST_05
@@ -85,16 +84,24 @@ use constant USER_REAL_NAME_FIELD => 6;
                 /],
 );
 
-@EXPORT_OK        = map { @{ $_ } } values %EXPORT_TAGS;
+our @EXPORT_OK        = map { @{ $_ } } values %EXPORT_TAGS;
 $EXPORT_TAGS{all} = \@EXPORT_OK;
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Sys::Info::Constants - Constants for Sys::Info
+Sys::Info::Constants
+
+=head1 VERSION
+
+version 0.7805
 
 =head1 SYNOPSIS
 
@@ -103,12 +110,13 @@ Sys::Info::Constants - Constants for Sys::Info
 
 =head1 DESCRIPTION
 
-This document describes version C<0.7803> of C<Sys::Info::Constants>
-released on C<10 May 2013>.
-
 This module defines all the constants used inside C<Sys::Info> and it's
 subclasses.
 
+=head1 NAME
+
+Sys::Info::Constants - Constants for Sys::Info
+
 =head1 CONSTANTS
 
 Every constant can be imported individually or via import keys:
@@ -147,15 +155,13 @@ L<Sys::Info>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 - 2013 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2006 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.16.2 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
