@@ -1,14 +1,12 @@
 package Sys::Info::Device;
+$Sys::Info::Device::VERSION = '0.7805';
 use strict;
 use warnings;
-use vars qw( $VERSION );
 use constant SUPPORTED => qw( CPU BIOS );
 use Carp qw( croak );
 use base qw( Sys::Info::Base );
 use Sys::Info::Constants qw( OSID );
 
-$VERSION = '0.7802';
-
 BEGIN {
     MK_ACCESSORS: {
         no strict qw(refs);
@@ -54,9 +52,17 @@ sub _device_available {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Sys::Info::Device - Information about devices
+Sys::Info::Device
+
+=head1 VERSION
+
+version 0.7805
 
 =head1 SYNOPSIS
 
@@ -73,11 +79,12 @@ or
 
 =head1 DESCRIPTION
 
-This document describes version C<0.7802> of C<Sys::Info::Device>
-released on C<31 July 2011>.
-
 This is an interface to the available devices such as the C<CPU>.
 
+=head1 NAME
+
+Sys::Info::Device - Information about devices
+
 =head1 METHODS
 
 =head2 new DEVICE_ID
@@ -94,16 +101,13 @@ L<Sys::Info::Device::CPU>, L<Sys::Info>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 - 2011 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2006 by Burak Gursoy.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
