@@ -1,9 +1,8 @@
 package Sys::Info::OS;
+$Sys::Info::OS::VERSION = '0.7805';
 use strict;
 use warnings;
-use vars qw( $VERSION );
 use subs qw( LC_TYPE  );
-use vars qw( @ISA     );
 use base                 qw( Sys::Info::Base );
 use Carp                 qw( croak );
 use Sys::Info::Constants qw( OSID  );
@@ -25,8 +24,6 @@ BEGIN {
     *LC_CTYPE = sub () {} if $@ || ! $eok;
 }
 
-$VERSION = '0.7802';
-
 BEGIN {
     CREATE_SYNONYMS_AND_UTILITY_METHODS: {
         ## no critic (TestingAndDebugging::ProhibitProlongedStrictureOverride)
@@ -114,11 +111,17 @@ sub locale {
 
 1;
 
-__END__
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Sys::Info::OS - Detailed os information.
+Sys::Info::OS
+
+=head1 VERSION
+
+version 0.7805
 
 =head1 SYNOPSIS
 
@@ -160,11 +163,12 @@ Example:
 
 =head1 DESCRIPTION
 
-This document describes version C<0.7802> of C<Sys::Info::OS>
-released on C<31 July 2011>.
-
 Supplies detailed operating system information.
 
+=head1 NAME
+
+Sys::Info::OS - Detailed os information.
+
 =head1 METHODS
 
 =head2 new
@@ -234,12 +238,8 @@ vary among different systems.
 
 =head2 host_name
 
-
-
 =head2 time_zone
 
-
-
 =head2 product_type
 
 =head2 bitness
@@ -384,20 +384,20 @@ L<http://msdn.microsoft.com/library/en-us/sysinfo/base/osversioninfoex_str.asp>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 - 2011 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2006 by Burak Gursoy.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+__END__
+
+
 use Socket;
 sub network_name {
    my $self  = shift;
